@@ -7,7 +7,6 @@ from json.decoder import JSONDecodeError
 import requests
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
-
 from instagrapi import config
 from instagrapi.exceptions import (
     BadPassword,
@@ -56,7 +55,10 @@ def manual_input_code(self, username: str, choice=None):
     """
     code = None
     while True:
-        code = input(f"Enter code (6 digits) for {username} ({choice}): ").strip()
+
+        # code = input(f"Enter code (6 digits) for {username} ({choice}): ").strip()
+        from boostedchatScrapper.spiders.helpers.instagram_login_helper import challenge_code_handler_
+        code  = challenge_code_handler_(username)
         if code and code.isdigit():
             break
     return code  # is not int, because it can start from 0
@@ -65,7 +67,9 @@ def manual_input_code(self, username: str, choice=None):
 def manual_change_password(self, username: str):
     pwd = None
     while not pwd:
-        pwd = input(f"Enter password for {username}: ").strip()
+        from boostedchatScrapper.spiders.helpers.instagram_login_helper import change_password_handler_
+        pwd = change_password_handler_(username)
+        # pwd = input(f"Enter password for {username}: ").strip()
     return pwd
 
 
